@@ -418,12 +418,15 @@ def meta_count( ) :
     return( count )
 
 
-def meta_read( mn ) :
+def meta_read( mn , raw = False ) :
 
     sql = "SELECT * FROM meta where mn='" + mn + "' limit 1"
     row = sql_execute_fetch( sql )
     if( not row ) : return( False )
-    return( json.loads( row[ "mv" ] )  )
+    if(raw):
+        return( row[ "mv" ] )
+    else:
+        return( json.loads( row[ "mv" ] ) )
 
 def meta_readall( ) :
     rows = table_readall( "meta" )
@@ -629,7 +632,9 @@ def files_getcontent( fp ) :
         return( False )
     return( f[ "fc" ] )
 
+# with open( dir_cache + "local_out.png" , "wb" ) as f :
 def files_write( fp ) :
+    # FIXME TODO test this... with open( dir_cache + "local_out.png" , "wb" ) as f :
     with open( fp , "w" , 1 ) as f :
         f.write( files_getcontent( fp ) )
 
