@@ -129,6 +129,11 @@ def job_request( params = { } ) :
     headers = { "X-Omni-Action": "job_request" }
     headers[ "X-Omni-Params" ] = s_util.json_encode( params )
 
+    header_extra=s_config.get_key( "_header_extra" )
+    if(header_extra):
+        s_log.write("FOUND _header_extra")
+        headers[ "X-Omni-Extra" ] = s_util.json_encode( header_extra )
+
     s_log.write( headers )
 
     res = get_request_response( headers , payload )
@@ -233,7 +238,7 @@ def job_response( jid ) :
 
 ####################################################################
 
-def job_get( queues_list =False ) :
+def job_get( queues_list = False ) :
 
     #if( not s_util.ready( ) ) :
     #    s_log.write( "NOT READY" )
@@ -250,7 +255,7 @@ def job_get( queues_list =False ) :
         env_queue=s_util.environ_get("_CONTAINER_LOCAL_APPQUEUE") ;
         if(env_queue):
             if not env_queue.endswith( "_LOCAL_APPQUEUE_" ) : 
-                s_log.write("FOUND _CONTAINER_LOCAL_APPQUEUE "+env_queue)
+                #s_log.write("FOUND _CONTAINER_LOCAL_APPQUEUE "+env_queue)
                 headers["X-Omni-Queue"]=env_queue
         else:
             s_log.write("NOT FOUND _CONTAINER_LOCAL_APPQUEUE")
