@@ -14,7 +14,7 @@
 #####################################################################
 
 import importlib
-from . import s_log , s_config , s_net , s_util , s_db , s_cleanup
+from . import s_log , s_config , s_net , s_util , s_db , s_cache , s_cleanup 
 
 #####################################################################
 
@@ -46,11 +46,18 @@ def config_load_from_file( cp ) :
 def prexit( msg ) :
     s_util.printexit( msg )
 
-def defdata( ) :
-    return( s_db.meta_read( "_data" ) )
+def exitiferror( ) :
+    if( geterror( ) ) :
+        prexit( geterror( ) )
 
-def defmeta( ) :
-    return( s_db.meta_read( "_meta" ) )
+def defdata( raw=False ) :
+    return( s_db.meta_read( "_data" , raw ) )
+
+def defmeta( raw=False) :
+    return( s_db.meta_read( "_meta" , raw ) )
+
+def geterror( ) :
+    return( s_db.meta_read( "_error" ) )
 
 def flush( ) :
     return( s_db.flush( ) )
@@ -203,7 +210,22 @@ def runner_omnibus( path_runner ) :
 
         #####################################################
 
-        runner_exitcode = _sapi_runner_omnibus._entrypoint( )
+        # FIXME TODO add try catch
+
+        try :
+            runner_exitcode = _sapi_runner_omnibus._entrypoint( )
+            if( runner_exitcode > 0 ) :
+                s_log.write( "ERROR _sapi_runner_omnibus runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
+                continue
+        except Exception as e :
+            #ERROR _sapi_runner_omnibus Exception module 'sapiadapter.sapiadapter' has no attribute 'write'
+
+            s_log.write( "ERROR _sapi_runner_omnibus Exception " + str( e ) , consoleprint = True )
+            s_util.printexception( e )
+            s_util.sleep( 3 )
+            continue
+
+        #runner_exitcode = _sapi_runner_omnibus._entrypoint( )
         s_log.write( "runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
 
         #####################################################
